@@ -5,13 +5,17 @@ ADA = Coin("ADA")
 ALGO = Coin("ALGO")
 ANKR = Coin("ANKR")
 ATOM = Coin("ATOM")
+AUDIO = Coin("AUDIO")
+AVAX = Coin("AVAX")
 BAL = Coin("BAL")
 BAND = Coin("BAND")
 BAT = Coin("BAT")
 BCH = Coin("BCH")
 BNT = Coin("BNT")
+BOSON = Coin("BOSON")
 BTC = Coin("BTC")
 CELR = Coin("CELR")
+CHR = Coin("CHR")
 CHZ = Coin("CHZ")
 COMP = Coin("COMP")
 CRO = Coin("CRO")
@@ -27,7 +31,9 @@ ETH = Coin("ETH")
 FIL = Coin("FIL")
 FLOW = Coin("FLOW")
 GRT = Coin("GRT")
+HOT = Coin("HOT")
 ICX = Coin("ICX")
+KAVA = Coin("KAVA")
 KNC = Coin("KNC")
 KSM = Coin("KSM")
 LINK = Coin("LINK")
@@ -39,23 +45,34 @@ MCO = Coin("MCO")
 MKR = Coin("MKR")
 NEAR = Coin("NEAR")
 NEO = Coin("NEO")
+NKN = Coin("NKN")
 OCEAN = Coin("OCEAN")
+OGN = Coin("OGN")
 OMG = Coin("OMG")
+ONE = Coin("ONE")
+ONEINCH = Coin("1INCH")
 ONT = Coin("ONT")
 PAXG = Coin("PAXG")
 QTUM = Coin("QTUM")
+RARI = Coin("RARI")
 REN = Coin("REN")
 RLY = Coin("RLY")
+RSR = Coin("RSR")
+RVN = Coin("RVN")
 SAND = Coin("SAND")
 SKL = Coin("SKL")
 SNX = Coin("SNX")
+SOL = Coin("SOL")
+STORJ = Coin("STORJ")
 STX = Coin("STX")
+SUSHI = Coin("SUSHI")
 THETA = Coin("THETA")
 UMA = Coin("UMA")
 UNI = Coin("UNI")
 USDC = Coin("USDC")
 USDT = Coin("USDT")
 VET = Coin("VET")
+VTHO = Coin("VTHO")
 WAVE = Coin("WAVE")
 WAVES = Coin("WAVES")
 WBTC = Coin("WBTC")
