@@ -12,6 +12,7 @@ ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
 ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
 ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
 ATOM_USDT = Pair("ATOM_USDT", price_precision=3, quantity_precision=2)
+AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
 BAL_CRO = Pair("BAL_CRO", price_precision=2, quantity_precision=3)
 BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
 BAND_CRO = Pair("BAND_CRO", price_precision=3, quantity_precision=2)
@@ -27,6 +28,7 @@ BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
 BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
 CELR_CRO = Pair("CELR_CRO", price_precision=5, quantity_precision=1)
 CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
+CHR_USDT = Pair("CHR_USDT", price_precision=5, quantity_precision=1)
 CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
 COMP_CRO = Pair("COMP_CRO", price_precision=2, quantity_precision=3)
 COMP_USDT = Pair("COMP_USDT", price_precision=2, quantity_precision=5)
@@ -54,12 +56,18 @@ EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
 ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
 ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
 ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
+FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
 FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
+FLOW_CRO = Pair("FLOW_CRO", price_precision=2, quantity_precision=3)
+FLOW_USDT = Pair("FLOW_USDT", price_precision=3, quantity_precision=4)
 GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
+HOT_CRO = Pair("HOT_CRO", price_precision=5, quantity_precision=0)
+HOT_USDT = Pair("HOT_USDT", price_precision=6, quantity_precision=0)
 ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
 ICX_CRO = Pair("ICX_CRO", price_precision=3, quantity_precision=0)
 ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
+KAVA_USDT = Pair("KAVA_USDT", price_precision=4, quantity_precision=2)
 KNC_CRO = Pair("KNC_CRO", price_precision=3, quantity_precision=2)
 KNC_USDT = Pair("KNC_USDT", price_precision=4, quantity_precision=3)
 KSM_CRO = Pair("KSM_CRO", price_precision=2, quantity_precision=3)
@@ -83,10 +91,14 @@ NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
 NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
 NEO_CRO = Pair("NEO_CRO", price_precision=3, quantity_precision=2)
 NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
+NKN_USDT = Pair("NKN_USDT", price_precision=5, quantity_precision=1)
 OCEAN_USDT = Pair("OCEAN_USDT", price_precision=4, quantity_precision=2)
+OGN_USDT = Pair("OGN_USDT", price_precision=4, quantity_precision=2)
 OMG_BTC = Pair("OMG_BTC", price_precision=8, quantity_precision=4)
 OMG_CRO = Pair("OMG_CRO", price_precision=3, quantity_precision=2)
 OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
+ONEINCH_USDT = Pair("1INCH_USDT", price_precision=4, quantity_precision=2)
+ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
 ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
 ONT_CRO = Pair("ONT_CRO", price_precision=3, quantity_precision=2)
 ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
@@ -96,11 +108,16 @@ QTUM_CRO = Pair("QTUM_CRO", price_precision=3, quantity_precision=2)
 QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
 REN_CRO = Pair("REN_CRO", price_precision=4, quantity_precision=2)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
+RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
 SAND_CRO = Pair("SAND_CRO", price_precision=4, quantity_precision=2)
 SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
 SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
 SNX_CRO = Pair("SNX_CRO", price_precision=2, quantity_precision=3)
 SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
+SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
+STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
+STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
+SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
 THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
 UMA_BTC = Pair("UMA_BTC", price_precision=7, quantity_precision=4)
 UMA_CRO = Pair("UMA_CRO", price_precision=2, quantity_precision=4)
@@ -111,6 +128,7 @@ USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
 VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
 VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
 VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
+WAVES_USDT = Pair("WAVES_USDT", price_precision=3, quantity_precision=3)
 WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
 WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
 XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
